@@ -7,7 +7,7 @@
 #include "configuration.h"
 #include "../path.h"
 #include "../root-portal.h"
-#include "../root-portal-tiny.xpm"
+#include "root-portal-tiny.xpm"
 #include "preferences.h"
 
 #include <gdk/gdkx.h>
