@@ -5,13 +5,8 @@
 #include "modulemodifier.h"
 #include "../module_tree.h"
 
-#ifdef WITH_GNOME
 #include <gnome.h>
-#endif
-
-#ifdef WITH_GTK
 #include <gtk/gtk.h>
-#endif
 
 #include <vector>
 using namespace std;
