@@ -1,3 +1,4 @@
+#ifdef WITH_X
 #include "drawing_area.h"
 #include "rootwindow.h"
 #include "drawing_area_registry.h"
@@ -142,5 +143,5 @@ void DrawingArea::erase()
 //  //  #endif
 //          }
 //  }
-
+#endif
 
