@@ -1,3 +1,4 @@
+#ifdef WITH_X
 #include "drawing_area_registry.h"
 #include "drawing_area.h"
 
@@ -24,3 +25,4 @@ void DrawingAreaRegistry::unregister_da(DrawingArea *da)
 {
         das.erase(find(das.begin(), das.end(), da));
 }
+#endif
