@@ -2,11 +2,14 @@
 
 #include "common.h"
 
+#ifdef WITH_X
 #include <gnome-xml/parser.h>
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
-
 #include <gdk/gdkprivate.h>
+#include <gdk/gdkx.h>
+#endif
+
 #include <unistd.h>
 #include <signal.h>
 #include <fcntl.h>
@@ -30,14 +33,16 @@ using namespace std;
 
 #include "plugin.h"
 #include "root-portal.h"
+#include "module_registry.h"
+#include "utils.h"
+#include "modules/builtin_plugin_loader.h"
+#ifdef WITH_X
 #include "rootwindow.h"
 #include "drawing_area_registry.h"
 #include "tree_builder_xml.h"
 #include "tree_saver_xml.h"
-#include "module_registry.h"
-#include "utils.h"
-#include "modules/builtin_plugin_loader.h"
 #include "config/configuration.h"
+#endif
 
 #define DEFAULT_CONFIG CONFIG_DIR "/config.rdf"
 #define USER_PLUGIN_DIR CONFIG_DIR "/plugins"
@@ -177,7 +182,10 @@ string RootPortal::getPluginDir()
 }
 
 RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
-    : configurator(NULL),
+    :
+#ifdef WITH_X
+    configurator(NULL),
+#endif
       remote_configure_request(false)
 {
         string homeDir = getHomeDir();
@@ -185,12 +193,15 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
         load_settings();
 
         /* configuration variables */
-        int help = -1, enableVerbose = -1, version = -1;
-        int set_slave_mode = -1;
-        int ldconfigurator = -1, dontLdConfigurator = -1;
-        char *display_ = NULL;
+        int enableVerbose = -1;
         char *configuration_ = NULL;
         char *output_command_file_name = NULL;
+        int help = -1, version = -1;
+        int set_slave_mode = -1;
+#ifdef WITH_X
+        int ldconfigurator = -1, dontLdConfigurator = -1;
+        char *display_ = NULL;
+#endif
         
 #ifdef DEBUG
         int debug_enable = -1;
@@ -204,6 +215,7 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
                 }
         }
 
+#ifdef WITH_X
         /* this tells popt how to do magic on our variables */
         static const struct poptOption options[] = {
                 { "version", 'v', POPT_ARG_NONE, &version, 0,
@@ -231,6 +243,7 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
 #endif          
                 { NULL, '\0', 0, NULL, 0}
         };
+#endif
         
         if (!with_x) {
                 for (int i = 1; i < argc; i++) {
@@ -259,6 +272,7 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
         
         string display;
         if (with_x) {
+#ifdef WITH_X
                 gnome_program_init(PACKAGE, VERSION, LIBGNOMEUI_MODULE,
                                    argc, argv,
                                    GNOME_PARAM_POPT_TABLE, options,
@@ -272,6 +286,10 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
                         if (disp)
                                 display = disp;
                 }
+#else
+                cerr << "Root-Portal was configured --without-x, but the --no-x option was not given.\n";
+                throw StartupCancelled(-1);
+#endif
         }
         
         string configuration;
@@ -325,7 +343,9 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
                 }
         }
 
+#ifdef WITH_X
         setDisplay(display);
+#endif
         
         if (configuration == "") {
                 string rcfile = homeDir + "/" DEFAULT_CONFIG;
@@ -343,7 +363,7 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
 
 #ifdef TO_PORT
         if (with_x) {
-                if (fcntl(ConnectionNumber(gdk_display), F_SETFD, FD_CLOEXEC) < 0) {
+                if (fcntl(ConnectionNumber(GDK_WINDOW_DISPLAY()), F_SETFD, FD_CLOEXEC) < 0) {
                         cerr << "Cannot detach fork." << endl;
                         throw StartupCancelled(-1);
                 }
@@ -365,14 +385,17 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
         ModuleTree::instance()->init();
         
         if (!slave_mode) {
+#ifdef WITH_X
                 if (verbose)
                         cout << "reading configuration from \"" << configuration << "\"\n";
                 TreeBuilderXml::instance()->load_file(configuration);
+#endif
         }
         if (output_command_file.is_open()) {
                 output_command_file.close();
         }
 
+#ifdef WITH_X
         if (with_x) {
                 configurator = new Configuration();
                 bool tmp = load_configurator_default;
@@ -383,6 +406,7 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
                 if (tmp)
                         configure();
         }
+#endif
 }
 
 RootPortal::~RootPortal()
@@ -394,17 +418,21 @@ RootPortal::~RootPortal()
 void RootPortal::service()
 {
         ModuleTree::instance()->service();
+#ifdef WITH_X
         if (remote_configure_request && configurator != NULL) {
                 remote_configure_request = false;
                 configurator->displayConfigurator();
         }
+#endif
         //	usleep(50); // was 1000, change back before you release
 }
 
 void RootPortal::saveConfig()
 {
+#ifdef WITH_X
         if (!slave_mode)
                 TreeSaverXml::instance()->save_to_file(writeConfig);
+#endif
 }
 
 void RootPortal::preShutdown()
@@ -451,17 +479,25 @@ void sigHandler(int sigNum)
                         time_to_shutdown = true;
         }
 }
+#ifndef WITH_X
+typedef int gint;
+typedef void *gpointer;
+#endif
 
 gint roundnroundnroundwego(gpointer data)
 {
+#ifdef WITH_X
         handle_x_events();
+#endif
         try {
                 rootPortal->service();
         } catch (...) {
                 cerr << "uncaught exception\n";
         }
+#ifdef WITH_X
         if (time_to_shutdown && with_x)
                 gtk_main_quit();
+#endif
         if (slave_mode) {
                 set_blocking(0, false);
                 static string text;
@@ -511,10 +547,12 @@ int main(int argc, char* argv[])
                 rootPortal = new RootPortal(argc, argv);
 
                 if (with_x) {
+#ifdef WITH_X
                         gtk_timeout_add(15, &roundnroundnroundwego, NULL);
                         rpdbgmsg("entering gtk_main()");
                         gtk_main();
                         rpdbgmsg("exited gtk_main()");
+#endif
                 } else {
                         while (!time_to_shutdown) {
                                 roundnroundnroundwego(NULL);
@@ -529,22 +567,27 @@ int main(int argc, char* argv[])
                 ModuleTree::destroy_instance();
                 Plugins::destroy_instance();
                 ModuleRegistry::destroy_instance();
+#ifdef WITH_X
                 DrawingAreaRegistry::destroy_instance();
 #ifdef WITH_XML
                 TreeBuilderXml::destroy_instance();
                 TreeSaverXml::destroy_instance();
 #endif
-                
+#endif
                 verbose = 0;
                 dev_null.close();
                 if (output_command_file.is_open())
                         output_command_file.close();
 
+#ifdef WITH_X
                 if (with_x)
                         gtk_exit(0);
+#endif
                 return 0;
         } catch (StartupCancelled ex) {
+#ifdef WITH_X
                 gtk_exit(ex.returnCode);
+#endif
                 return ex.returnCode;
         }
 }
