@@ -21,23 +21,13 @@ const DataSetMap& Console::get_module_info_instance()
         return *moduleInfo;
 }
 
-extern "C" int
-#ifdef BUILDIN_CONSOLE
-console_plugin_startup()
-#else
-plugin_startup()
-#endif
+extern "C" int console_plugin_startup()
 {
         ModuleRegistry::instance()->add_module("Console", &console_constructor, Console::get_module_info_instance());
         return 0;
 }
 
-extern "C" void
-#ifdef BUILDIN_CONSOLE
-console_plugin_shutdown()
-#else
-plugin_shutdown()
-#endif
+extern "C" void console_plugin_shutdown()
 {
         ModuleRegistry::instance()->remove_module("Console");
         Console::destroy_module_info();
