@@ -1,3 +1,4 @@
+#ifdef WITH_X
 #include "gnometext.h"
 #include "../../module_registry.h"
 #include <X11/Xlib.h>
@@ -370,3 +371,4 @@ void GnomeText::display()
         }
         zvt_term_feed(ZVT_TERM(term), const_cast<char*> (newdata.c_str()), newdata.length());
 }
+#endif
