@@ -1,3 +1,4 @@
+#ifdef WITH_X
 /* there is some code duplication between this and roottext.  this should probably be eliminated by making a common class
  * for the two.
  */
@@ -323,3 +324,4 @@ void Graph::outputReceived(const DataSetMap& output)
                 }
         }
 }
+#endif
