@@ -1,3 +1,4 @@
+#ifdef WITH_X
 #include "roottext.h"
 #include "../../module_registry.h"
 
@@ -261,4 +262,4 @@ Pixel Roottext::getColour(const string& colourName)
 		cerr << "can't allocate " << colourName << endl;
 	return colour.pixel;
 }
-
+#endif
