@@ -1,3 +1,4 @@
+#ifdef WITH_X
 #include "shell.h"
 #include "sub_process.h"
 #include "../../module_registry.h"
@@ -142,3 +143,4 @@ void Shell::execute()
         if (periodic_cmd != "")
                 periodic = new SubProcess(periodic_cmd);
 }
+#endif
