@@ -83,7 +83,7 @@ void SystemLoad::service()
                 last_ticks = ticks;
                 last_total = total;
 
-                if (!first) {
+                if (!first && d_ticks > 0) {
                         addToOutput("cpu_user", DataSet((d_user * 100) / d_ticks));
                         addToOutput("cpu_nice", DataSet((d_nice * 100) / d_ticks));
                         addToOutput("cpu_system", DataSet((d_system * 100) / d_ticks));
