@@ -1,3 +1,4 @@
+#ifdef WITH_X
 #include "tree_saver_xml.h"
 #include "module_tree.h"
 
@@ -56,3 +57,4 @@ void TreeSaverXml::save_to_file(const string& filename)
 
         xmlFreeDoc(doc);
 }
+#endif
